@@ -47,14 +47,14 @@ use crate::{
     error::{ErrorFormatter, PrettyError},
     hub::{GlobalIdentityHandlerFactory, HalApi, Hub, Resource, Storage, Token},
     id,
-    init_tracker::{BufferInitTrackerAction, MemoryInitKind},
+    init_tracker::{BufferInitTrackerAction, MemoryInitKind, TextureInitTrackerAction},
     pipeline::PipelineFlags,
     track::{TrackerSet, UsageConflict},
     validation::check_buffer_usage,
     Label, LabelHelpers, LifeGuard, Stored,
 };
 use arrayvec::ArrayVec;
-use std::{borrow::Cow, mem, ops::Range};
+use std::{borrow::Cow, mem, num::NonZeroU32, ops::Range};
 use thiserror::Error;
 
 use hal::CommandEncoder as _;
@@ -75,6 +75,8 @@ pub struct RenderBundleEncoderDescriptor<'a> {
     /// Sample count this render bundle is capable of rendering to. This must match the pipelines and
     /// the renderpasses it is used in.
     pub sample_count: u32,
+    /// If this render bundle will rendering to multiple array layers in the attachments at the same time.
+    pub multiview: Option<NonZeroU32>,
 }
 
 #[derive(Debug)]
@@ -112,6 +114,7 @@ impl RenderBundleEncoder {
                     }
                     sc
                 },
+                multiview: desc.multiview,
             },
             is_ds_read_only: match desc.depth_stencil {
                 Some(ds) => {
@@ -135,6 +138,7 @@ impl RenderBundleEncoder {
                     depth_stencil: None,
                 },
                 sample_count: 0,
+                multiview: None,
             },
             is_ds_read_only: false,
         }
@@ -180,6 +184,7 @@ impl RenderBundleEncoder {
         let mut base = self.base.as_ref();
         let mut pipeline_layout_id = None::<id::Valid<id::PipelineLayoutId>>;
         let mut buffer_memory_init_actions = Vec::new();
+        let mut texture_memory_init_actions = Vec::new();
 
         for &command in base.commands {
             match command {
@@ -233,6 +238,7 @@ impl RenderBundleEncoder {
                     }
 
                     buffer_memory_init_actions.extend_from_slice(&bind_group.used_buffer_ranges);
+                    texture_memory_init_actions.extend_from_slice(&bind_group.used_texture_ranges);
 
                     state.set_bind_group(index, bind_group_id, bind_group.layout_id, offsets);
                     state
@@ -523,6 +529,7 @@ impl RenderBundleEncoder {
             },
             used: state.trackers,
             buffer_memory_init_actions,
+            texture_memory_init_actions,
             context: self.context,
             life_guard: LifeGuard::new(desc.label.borrow_or_default()),
         })
@@ -587,6 +594,7 @@ pub struct RenderBundle {
     pub(crate) device_id: Stored<id::DeviceId>,
     pub(crate) used: TrackerSet,
     pub(super) buffer_memory_init_actions: Vec<BufferInitTrackerAction>,
+    pub(super) texture_memory_init_actions: Vec<TextureInitTrackerAction>,
     pub(super) context: RenderPassContext,
     pub(crate) life_guard: LifeGuard,
 }
