@@ -578,7 +578,7 @@ impl<'a, A: HalApi> RenderPassInfo<'a, A> {
         } else if channel.store_op == StoreOp::Store {
             // Clear + Store
             texture_memory_actions.register_implicit_init(
-                view.parent_id.value.0,
+                view.parent_id.value,
                 TextureInitRange::from(view.selector.clone()),
                 texture_guard,
             );
@@ -745,7 +745,7 @@ impl<'a, A: HalApi> RenderPassInfo<'a, A> {
                 if at.depth.store_op != at.stencil.store_op {
                     if !need_init_beforehand {
                         cmd_buf.texture_memory_actions.register_implicit_init(
-                            view.parent_id.value.0,
+                            view.parent_id.value,
                             TextureInitRange::from(view.selector.clone()),
                             texture_guard,
                         );
@@ -838,7 +838,7 @@ impl<'a, A: HalApi> RenderPassInfo<'a, A> {
                 }
 
                 cmd_buf.texture_memory_actions.register_implicit_init(
-                    resolve_view.parent_id.value.0,
+                    resolve_view.parent_id.value,
                     TextureInitRange::from(resolve_view.selector.clone()),
                     texture_guard,
                 );
